@@ -1,19 +1,7 @@
 package SQL::Dialects::ANSI;
 
-
-=head1 NAME
-
- SQL::Dialects::ANSI -- ANSI config file for SQL::Parse
-
-=head1 SYNOPSIS
-
-  see SQL::Parse, SQL::Squish
-
-=head1 DESCRIPTION
-
- The makemaker police say i gotta have one of these
-
-=cut
+use vars qw($VERSION);
+$VERSION = '0.1';
 
 sub get_config {
 return <<EOC;
